# DevAutomator

Your Personal Dev Automation Assistant - A powerful CLI tool that streamlines your development workflow by automating common development tasks.

## Overview

DevAutomator is designed to enhance developer productivity by providing a comprehensive suite of automation tools. It simplifies project setup, testing, documentation, and maintenance tasks, allowing you to focus on what matters most - writing great code.

## Features

- **Project Initialization**: Quickly set up new projects with best practices
- **Infrastructure as Code**: Generate Terraform configurations
- **Containerization**: Create Docker and Docker Compose configurations
- **Environment Management**: Set up Python virtual environments
- **Testing**: Run and manage tests with pytest
- **Documentation**: Generate and maintain project documentation
- **Dependency Management**: Track and update project dependencies
- **Project Scaffolding**: Create new projects with industry-standard templates
- **Cleanup Tools**: Remove temporary files and cache
- **Project Metrics**: Monitor project health and status

## Installation

Install DevAutomator using pip:

```bash
pip install devautomator
```

## Quick Start

After installation, you can access DevAutomator from your terminal:

```bash
devautomator --help
```

## Available Commands

- `tf`: Initialize Terraform projects
- `docker`: Create Docker configurations
- `env`: Set up Python virtual environments
- `test`: Run project tests
- `doc`: Generate project documentation
- `dep`: Check dependency status
- `scaffold`: Create new project templates
- `mkdoc`: Generate markdown documentation
- `cleanup`: Remove temporary files
- `dashboard`: View project metrics

## Project Structure

DevAutomator follows a modular design, making it easy to extend and customize. The project structure includes:

- Core automation modules
- Command-line interface
- Configuration management
- Template system
- Utility functions

## Contributing

We welcome contributions! To contribute to DevAutomator:

1. Fork the repository
2. Create a feature branch
3. Make your changes
4. Submit a pull request

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Support

For support, please open an issue in the GitHub repository or contact the maintainers.

## Acknowledgments

- Thanks to all contributors who have helped shape DevAutomator
- Built with Python and Click
- Inspired by the need for better developer automation tools
